@@ -40,6 +40,11 @@ Configuration = {
 	"stat_error_max_count": 1000,
 	"stat_useragent_max_count": 500,
 
+    "user_header_ticket_enabled": False,
+    "user_header_ticket":"",
+    "trace_user_cookie_limit":2048,
+    "trace_user_cookie_domain":"",
+
     # "whatap_server_host": "127.0.0.1/127.0.0.1",
     # "whatap_server_port": 6600,
     # "mode": "whatap_dev",
