@@ -5,12 +5,20 @@ from whatap.trace.mod.application_wsgi import interceptor, trace_handler, \
     interceptor_error
 from whatap.trace.trace_context_manager import TraceContextManager
 from whatap.util.date_util import DateUtil
+from whatap.util.userid_util import UseridUtil as userid_util
+import time
 
-
+init_load_interval=  30
 def instrument(module):
     def wrapper(fn):
         @trace_handler(fn, True)
         def trace(*args, **kwargs):
+            try:
+                now = int(time.time())
+                if now - conf.last_loaded > init_load_interval:
+                    conf.init(False)
+            except Exception as e:
+                print(e)
             callback = interceptor(fn, *args, **kwargs)
             
             return callback
@@ -55,10 +63,10 @@ def instrument_handlers_base(module):
             return callback
         
         return trace
-    
-    module.BaseHandler.apply_response_fixes = wrapper(
-        module.BaseHandler.apply_response_fixes)
-    
+
+    if hasattr(module.BaseHandler, 'apply_response_fixes'):
+        module.BaseHandler.apply_response_fixes = wrapper(
+            module.BaseHandler.apply_response_fixes)
     def wrapper(fn):
         @trace_handler(fn)
         def trace(*args, **kwargs):
@@ -75,9 +83,27 @@ def instrument_handlers_base(module):
             return callback
         
         return trace
-    
-    module.BaseHandler.handle_uncaught_exception = wrapper(
-        module.BaseHandler.handle_uncaught_exception)
+
+    if hasattr(module.BaseHandler, 'handle_uncaught_exception'):
+        module.BaseHandler.handle_uncaught_exception = wrapper(
+            module.BaseHandler.handle_uncaught_exception)
+
+    def get_response_wrapper(fn):
+        @trace_handler(fn)
+        def trace(*args, **kwargs):
+
+            request = args[1]
+            callback = fn(*args, **kwargs)
+
+            ctx = TraceContextManager.getLocalContext()
+            if ctx and conf.trace_user_enabled:
+                if not conf.trace_user_using_ip:
+                    userid_util.setUserId(request, callback, ctx._rawuserid )
+            return callback
+
+        return trace
+    module.BaseHandler.get_response = get_response_wrapper(
+        module.BaseHandler.get_response)
 
 
 def instrument_generic_base(module):
@@ -102,6 +128,8 @@ def instrument_generic_base(module):
     module.View.dispatch = wrapper(module.View.dispatch)
 
 
+
+
 # Django==1.10
 
 def instrument_urls_base(module):
@@ -127,3 +155,21 @@ def instrument_handlers_exception(module):
     
     module.convert_exception_to_response.convert_exception_to_response = wrapper(
         module.convert_exception_to_response.convert_exception_to_response)
+
+def instrument_handlers_static(module):
+    def get_response_wrapper(fn):
+        @trace_handler(fn)
+        def trace(*args, **kwargs):
+            callback = fn(*args, **kwargs)
+
+            ctx = TraceContextManager.getLocalContext()
+            if ctx:
+                ctx.userid = 0
+
+            return callback
+
+        return trace
+
+    module.StaticFilesHandler.get_response = get_response_wrapper(
+        module.BaseHandler.get_response)
+
