@@ -8,6 +8,7 @@ from whatap.net.udp_session import UdpSession
 from whatap.trace.trace_context import TraceContext
 from whatap.trace.trace_context_manager import TraceContextManager
 from whatap.util.date_util import DateUtil
+from whatap.util.userid_util import UseridUtil as userid_util
 from functools import wraps
 from whatap import logging
 import re
@@ -77,6 +78,7 @@ def end_interceptor(thread_id=None):
     datas = [ctx.host, ctx.service_name, ctx.mtid, ctx.mdepth, ctx.mcaller_txid,
              ctx.mcaller_pcode, ctx.mcaller_spec, ctx.mcaller_url]
     ctx.elapsed = DateUtil.nowSystem() - start_time
+
     UdpSession.send_packet(PacketTypeEnum.TX_END, ctx, datas)
 
 
@@ -98,8 +100,8 @@ def interceptor(rn_environ, *args, **kwargs):
         if conf.trace_user_using_ip:
             ctx.userid = ctx.remoteIp
         else:
-            ctx.userid = ctx.remoteIp  # TODO cookie
-    
+            ctx.userid, ctx._rawuserid = userid_util.getUserId(args, ctx.remoteIp)
+
     mstt = environ.get('HTTP_{}'.format(
         conf._trace_mtrace_caller_key.upper().replace('-', '_')), '')
     
@@ -116,11 +118,10 @@ def interceptor(rn_environ, *args, **kwargs):
             conf._trace_mtrace_callee_key.upper().replace('-', '_')), '')
         if myid:
             ctx.setTxid(myid)
-    
     start_interceptor(ctx)
     
     callback = fn(*args, **kwargs)
-    
+
     ctx = TraceContextManager.getLocalContext()
     if ctx:
         query_string = environ.get('QUERY_STRING', '')
@@ -151,7 +152,6 @@ def interceptor(rn_environ, *args, **kwargs):
             datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
             ctx.start_time = DateUtil.nowSystem()
             UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
-        
         end_interceptor()
     return callback
 
